#
# spec file for package godot
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2017 Luke Jones, luke.nukem.jones@gmail.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# faster_build only builds the editor to speed up the build.
%define faster_build 0

%define _buildshell /bin/bash
# not needed anymore since 4.1
%define ca_bundle %{_localstatedir}/lib/ca-certificates/ca-bundle.pem

# building with default gcc 7.5 fails since 4.1 on Leap
# https://github.com/godotengine/godot/issues/79352
%define compiler_version_leap 10

Name:           godot
Version:        4.4.1
Release:        1.2
Summary:        Cross-Platform Game Engine with an Integrated Editor
License:        MIT
Group:          Development/Tools/Other
URL:            https://godotengine.org/
Source0:        https://github.com/godotengine/%{name}/releases/download/%{version}-stable/%{name}-%{version}-stable.tar.xz
Source1:        https://github.com/godotengine/%{name}/releases/download/%{version}-stable/%{name}-%{version}-stable.tar.xz.sha256
BuildRequires:  Mesa-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
%if %{suse_version} > 1500
BuildRequires:  gcc
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc%{compiler_version_leap}
BuildRequires:  gcc%{compiler_version_leap}-c++
%endif
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  scons > 4.5
BuildRequires:  wayland-devel
BuildRequires:  yasm-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(libdecor-0)
BuildRequires:  pkgconfig(libpcre2-32)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(speech-dispatcher)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(theoradec)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)

%if 0%{?suse_version} > 1500
# Does not work currently:
# BuildRequires:  embree-devel-static >= 3.13.0

# https://github.com/godotengine/godot/issues/64090 :
#   unbundled freetype needs to be build with brotli decompression support
#   to load build in WOFF2 editor fonts since godot version 3.5.
# This was added according to
#   https://build.opensuse.org/package/view_file/M17N/freetype2/freetype2.changes
#   in freetype2 version 2.10.2
# By default this seems to be currently only available in Tumbleweed (v2.12.1).
# As of 20220808 Leap 15.2, .3 and .4 report freetype2 version as 2.10.1
BuildRequires:  pkgconfig(freetype2) >= 2.10.2
# Using bundled freetype2 throws build errors, if
#   we don't use bundled libpng and zlib as well.
BuildRequires:  pkgconfig(libpng)
BuildRequires:  mbedtls-devel
BuildRequires:  pkgconfig(graphite2)
BuildRequires:  pkgconfig(libbrotlicommon)
BuildRequires:  pkgconfig(libbrotlidec)
BuildRequires:  pkgconfig(libwslay)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(miniupnpc)
BuildRequires:  pkgconfig(zlib)
%else
%if 0%{?is_opensuse}
# SLES seems not to have wslay and miniupnpc
BuildRequires:  libminiupnpc-devel
BuildRequires:  pkgconfig(libwslay)
%if 0%{?sle_version} >= 150200
BuildRequires:  mbedtls-devel
%endif
%endif
%endif

Requires:       ca-certificates
Recommends:     ca-certificates-mozilla
Suggests:       %{name}-runner = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

# The following "Provides: bundled()" and comments were taken from the
# Fedora Godot specfile.
# Link: https://src.fedoraproject.org/rpms/godot/blob/master/f/godot.spec

# Has some modifications for IPv6 support, upstream enet is unresponsive
# Should not be unbundled.
Provides:       bundled(enet) = 1.3.18

# Has custom changes to support seeking in zip archives
# Should not be unbundled.
Provides:       bundled(minizip) = 1.3.1
Provides:       bundled(FastLZ)
Provides:       bundled(FastNoiseLite)
Provides:       bundled(JetBrainsMono_Regular)
Provides:       bundled(RVO2-3D)
Provides:       bundled(Tangent_Space_Normal_Maps)
Provides:       bundled(amd-fsr) = 1.0.2
Provides:       bundled(amd-fsr2) = 2.2.1
Provides:       bundled(angle)
Provides:       bundled(astcenc) = 4.8.0
Provides:       bundled(basis_universal) = 1.50.0
Provides:       bundled(clipper2) = 1.4.0
Provides:       bundled(cvtt)
Provides:       bundled(d3d12ma) = 2.1.0
Provides:       bundled(directx_headers) = 1.611.1
Provides:       bundled(doctest) = 2.4.11
Provides:       bundled(etcpak) = 2.0
Provides:       bundled(glad) = 2.0.4
# same version for glslang, spirv-reflect, volk and vulkan needed
Provides:       bundled(glslang) = sdk-1.3.283.0
Provides:       bundled(google-droid-fonts)
# gdextension crash with unbundled harfbuzz or icu4c
# https://github.com/godotengine/godot/issues/91401
Provides:       bundled(harfbuzz) = 10.1.0
Provides:       bundled(icu4c) = 76.1
Provides:       bundled(ifaddrs-android)
Provides:       bundled(jolt_physics) = 5.2.1
Provides:       bundled(jpeg-compressor) = 2.00
Provides:       bundled(libbacktrace)
Provides:       bundled(libktx) = 4.3.2
Provides:       bundled(manifold) = 3.0.1
Provides:       bundled(meshoptimizer) = 0.22
Provides:       bundled(mingw-std-threads)
Provides:       bundled(minimp3)
Provides:       bundled(msdfgen) = 1.12
Provides:       bundled(noto-sans-fonts)
Provides:       bundled(nvapi) = R525
Provides:       bundled(openxr) = 1.1.41
Provides:       bundled(pcg)
Provides:       bundled(polyclipping)
Provides:       bundled(polypartition)
Provides:       bundled(pvrtccompressor)
Provides:       bundled(qoa)
Provides:       bundled(smaz)
Provides:       bundled(spirv-cross)
Provides:       bundled(spirv-reflect) = sdk-1.3.283.0
Provides:       bundled(stb)
Provides:       bundled(thorvg) = 0.15.10
Provides:       bundled(tinyexr) = 1.0.9
Provides:       bundled(ufbx) = 0.15.0
Provides:       bundled(vhacd)
Provides:       bundled(volk) = sdk-1.3.283.0
Provides:       bundled(vulkan) = sdk-1.3.283.0
Provides:       bundled(wayland) = 1.22.0
Provides:       bundled(wayland-protocols) = 1.33
Provides:       bundled(yuv2rgb)

# Can be unbundled if packaged
Provides:       bundled(recastnavigation) = 1.6.0
Provides:       bundled(xatlas)

# Embree 3.13.0+ supports both x86_64 and aarch64.
# per 20211108 Factory is at 3.13.0, Leap at 3.8 .
# Currently build fails with Distro (unbundled) embree on Tumbleweed although
# the required version is available.
# Perhaps because it is build with special flags (static) for blender.
Provides:       bundled(embree) = 4.3.1

%if 0%{?suse_version} > 1500
%else
Provides:       bundled(brotli) = 1.1.0

# see comments for freetype2, libpng and zlib Factory BuildRequires
Provides:       bundled(freetype2) = 2.13.2
Provides:       bundled(graphite) = 1.3.14
Provides:       bundled(libpng) = 1.6.45
Provides:       bundled(libzstd) = 1.5.6
Provides:       bundled(zlib) = 1.3.1
%if 0%{?sle_version} < 150200
Provides:       bundled(mbedtls) = 3.6.3
%endif
%if !0%{?is_opensuse}
# SLES seems not to have miniupnpc and wslay
Provides:       bundled(libwslay) = 1.1.1
Provides:       bundled(miniupnpc) = 2.2.8
%endif
%endif

# Build currently fails on armv7l
ExcludeArch:    %arm

%description
Godot is a game engine. It provides a set of tools and a visually
oriented workflow that can export games to PC, Mobile and Web
platforms.

%if !0%{?faster_build}
%package runner
Summary:        Shared binary to play games developed with the Godot engine
Group:          Amusements/Games/Other
Requires:       ca-certificates
Recommends:     ca-certificates-mozilla
Suggests:       %{name}-bash-completion

%description runner
This package contains a godot-runner binary for the Linux X11 platform,
which can be used to run any game developed with the Godot engine simply
by pointing to the location of the game's data package.
%endif

%package bash-completion
Summary:        Godot command line completion for Bash
Group:          Amusements/Games/Other
BuildArch:      noarch
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
Enhances:       (%{name}-runner and bash-completion)

%description bash-completion
Bash command line completion support for %{name} and %{name}-runner

%prep
%autosetup -p1 -n %{name}-%{version}-stable

cp thirdparty/README.md thirdparty_README.md

# actual doc location in openSUSE
sed -i 's/\/usr\/share\/doc\/godot\//\/usr\/share\/doc\/packages\/godot\//' misc/dist/linux/godot.6

if [[ -z "$(desktop-file-validate misc/dist/linux/org.godotengine.Godot.desktop)" ]];
 then
  # desktop-file-utils version >= 0.25
  echo desktop-file-utils is up to date and recognizes PrefersNonDefaultGPU.
  # rpmlint complains nevertheless with older rpmlint-mini.
  # Tumbleweed is fixed with update of rpmlint-mini.
  # see https://specifications.freedesktop.org/desktop-entry-spec/desktop-entry-spec-latest.html#recognized-keys
  # Perhaps because rpmlint-mini includes as of today (18.09.2020)
  # desktop-file-utils-0.24 while we checked for available default version >= 0.25
 else
  echo PrefersNonDefaultGPU not recognized.
  # rpmlint considers file invalid without "X-" prefix
  sed -i 's/PrefersNonDefaultGPU=true/X-PrefersNonDefaultGPU=true/' misc/dist/linux/org.godotengine.Godot.desktop
fi

# disarm shebang
sed -i '1s/#!/##/' misc/dist/shell/godot.bash-completion

# bash completion for sub package
cp misc/dist/shell/godot.bash-completion misc/dist/shell/godot-runner
sed -i '$s/_complete_godot_bash godot/_complete_godot_bash godot-runner/' misc/dist/shell/godot-runner

# set update check default to disabled
sed -i 's/EngineUpdateLabel::UpdateMode default_update_mode = EngineUpdateLabel::UpdateMode::NEWEST_UNSTABLE;/EngineUpdateLabel::UpdateMode default_update_mode = EngineUpdateLabel::UpdateMode::DISABLED;/' editor/editor_settings.cpp
sed -i 's/default_update_mode = EngineUpdateLabel::UpdateMode::NEWEST_STABLE;/default_update_mode = EngineUpdateLabel::UpdateMode::DISABLED;/' editor/editor_settings.cpp

%build
# Configuring build to use some distribution libraries
unbundle_libs=('certs' 'libogg' 'libtheora' 'libvorbis' \
               'libwebp' 'pcre2')

# Adding distribution name to build name
%if 0%{?suse_version}
  %if 0%{?is_opensuse}
    # Unbundle more libs for openSUSE
    unbundle_libs+=('miniupnpc' 'wslay')
    export BUILD_NAME="openSUSE"
  %else
    export BUILD_NAME="SUSE"
  %endif
%endif

# Unbundle more libs for Tumbleweed
%if %{suse_version} > 1500
unbundle_libs+=('brotli' 'freetype' 'graphite' 'libpng' 'mbedtls' 'zlib' 'zstd')
%else
# Unbundle more libs for coming Leap
%if 0%{?sle_version} >= 150200 && 0%{?is_opensuse}
unbundle_libs+=('mbedtls')
%endif
%endif

system_libs=""
for thirdparty in "${unbundle_libs[@]}"; do
  system_libs="$system_libs builtin_$thirdparty=no"
  rm -rf thirdparty/$thirdparty
done

# Keep empty certificates file needed as "source" by
# function "make_certs_header" in core/core_builders.py
mkdir -pv thirdparty/certs
touch thirdparty/certs/ca-certificates.crt

use_lto="full"
use_sowrap="use_sowrap=no"
rm -rf thirdparty/linuxbsd_headers

%ifarch %ix86
# error since 4.4
# lto1: out of memory
# lto-wrapper: fatal error: g++ returned 1 exit status
# what to do ?
# increasing constraints or disable lto did not help
# => delete -flto from optflags
use_lto="none"
%define cc_flags -fomit-frame-pointer -O2 -Wall -U_FORTIFY_SOURCE -D_FORTIFY_SOURCE=3 -fstack-protector-strong -funwind-tables -fasynchronous-unwind-tables -fstack-clash-protection -Werror=return-type -g
%else
%define cc_flags %{optflags}
%endif

%if %{suse_version} > 1500
%define ccflags %{cc_flags}
compiler=""
linkflags=""
%else
%define ccflags %{cc_flags} -fPIE
compiler="CC=gcc-%{compiler_version_leap}  CXX=g++-%{compiler_version_leap}"
linkflags="linkflags=-pie"
%endif

%define build_args_common %{?_smp_mflags} \\\
        progress=no verbose=yes udev=yes lto=$use_lto debug_symbols=yes \\\
        use_static_cpp=no ccflags='%{ccflags}' $linkflags $compiler \\\
        engine_update_check=no steamapi=no \\\
        system_certs_path=%{ca_bundle} $use_sowrap $system_libs

%ifarch aarch64 %arm
# Disable unsupported features - https://github.com/godotengine/godot/issues/48297#issuecomment-829165296
%define build_args %{build_args_common} module_denoise_enabled=no
%else
%define build_args %{build_args_common}
%endif

# Build graphical editor
scons %{build_args} platform=linuxbsd target=editor

%if !0%{?faster_build}
# Build game runner
scons %{build_args} platform=linuxbsd target=template_release production=yes
%endif

%install
# build binary suffix
%ifarch riscv64
suffix=rv64
%else
%ifarch aarch64
suffix=arm64
%else
%ifarch ppc64 ppc64le
suffix=ppc64
%else
suffix=%{__isa_name}_%{__isa_bits}
%endif
%endif
%endif

# Installing the editor
install -D -p -m 755 bin/%{name}.linuxbsd.editor.$suffix %{buildroot}%{_bindir}/%{name}

install -D -p -m 644 misc/dist/linux/godot.6 %{buildroot}/%{_mandir}/man6/%{name}.6%{?ext_man}
install -D -p -m 644 icon.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
install -D -p -m 644 icon.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
install -D -p -m 644 misc/dist/linux/org.godotengine.Godot.appdata.xml  %{buildroot}%{_datadir}/metainfo/org.godotengine.Godot.appdata.xml
install -D -m 0644 misc/dist/linux/org.godotengine.Godot.desktop %{buildroot}%{_datadir}/applications/org.godotengine.Godot.desktop

%if !0%{?faster_build}
# Installing the runner
install -D -p -m 755 bin/%{name}.linuxbsd.template_release.$suffix %{buildroot}%{_bindir}/%{name}-runner
%endif

# Installing bash-completion
install -D -p -m 644 misc/dist/shell/godot.bash-completion %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -D -p -m 644 misc/dist/shell/godot-runner %{buildroot}%{_datadir}/bash-completion/completions/%{name}-runner

%fdupes -s %{buildroot}/%{_prefix}

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/org.godotengine.Godot.desktop

%files
%license LICENSE.txt LOGO_LICENSE.txt COPYRIGHT.txt thirdparty_README.md
%doc AUTHORS.md CHANGELOG.md CONTRIBUTING.md DONORS.md README.md logo.svg
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/256x256
%dir %{_datadir}/icons/hicolor/256x256/apps
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_bindir}/%{name}
%{_datadir}/metainfo/org.godotengine.Godot.appdata.xml
%{_datadir}/applications/org.godotengine.Godot.desktop
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man6/%{name}.6%{?ext_man}

%if !0%{?faster_build}
%files runner
%license LICENSE.txt LOGO_LICENSE.txt COPYRIGHT.txt thirdparty_README.md
%doc AUTHORS.md CHANGELOG.md CONTRIBUTING.md DONORS.md README.md logo.svg
%{_bindir}/%{name}-runner
%endif

%files bash-completion
%license LICENSE.txt COPYRIGHT.txt
%{_datadir}/bash-completion/completions/%{name}
%{_datadir}/bash-completion/completions/%{name}-runner

%changelog
* Wed Mar 26 2025 cunix@mail.de
- Update to 4.4.1
  * Fix TextEdit scrolls wrong on text selection
  * Restore "Show in File Manager" button functionality
    in ProjectManager
  * Update script modified times when saved in EditorNode
  * Create .uid files for detected new files
  * Set window position when running project in maximized
    or full-screen mode to ensure it is opened on the correct screen
  * Add "Go Online" button on Export Template Manager
  * Fix check for "is_maximized" to require both horizontal and vertical
  and more:
  https://godotengine.github.io/godot-interactive-changelog/#4.4.1
* Mon Mar  3 2025 cunix@mail.de
- Update to 4.4
  * Breaking changes: https://github.com/godotengine/godot/pulls?q=is%%3Apr+is%%3Amerged+label%%3A%%22breaks+compat%%22+milestone%%3A4.4
  * Jolt Physics
  * Interactive in-game editing
  * Embedded game window
  * Ubershaders
  * 3D physics interpolation
  * AgX tone mapping
  * Typed dictionaries
  * Universal UID support
  * 3D object snapping
  * Camera3D preview
  * Persistent window state
  * Camera support
  * Async navigation
  * Vertex shading
  * Rendering driver fallback
  * Emission shapes for 3D particle systems
  and much more:
  https://godotengine.github.io/godot-interactive-changelog/#4.4
- pointed source uri to github.com
- removed update-desktop-files
* Mon Feb 10 2025 Michal Suchanek <msuchanek@suse.de>
- Fix ppc64le build
* Thu Aug 15 2024 cunix@mail.de
- Update to 4.3
  * Interactive music
  * 2D physics interpolation
  * TileMapLayer nodes
  * SkeletonModifier3D node
  * Splitting navigation meshes into chunks
  * Native ufbx importer
  * Parallax2D node
  * Premultiplied alpha blending in 3D shaders
  * Depth-based fog
  * Acyclic rendering graph
  * Wayland support
  * Register runtime classes with GDExtension
  and much more:
  https://godotengine.github.io/godot-interactive-changelog/#4.3
- delete improve_linker_detection.patch
- update check mode set to "disabled" by default
* Mon Apr 22 2024 cunix@mail.de
- Update to 4.2.2
  * Texture2D and Texture3D icons added
  * Prompt require editor restart to user when gizmo color changed
  * Make viewport message dependent on framerate not physics step
  * Show modifier key functionality on all the editor tools
  * Make AnimationTree reference AnimationPlayer instead of AnimationMixer
  * Fix permanently selected audio bus effects
  * Add missing RenderServer include for "get_video_adapter_driver_info"
  * Fix frame number underflow in visual profiler
  * ix leak of scene used for customization during export
  * Handle export preset forward compat with 4.3+ platform name
  * Fix reporting exit code when command line export fails
  * Correctly enforce minimum window size in editor
  * Add "--import" command-line flag
  * Ensure the active window gains the keyboard focus
  * Prevent escape key from closing Editor Settings window when filtering for shortcuts
  * Fix Godot stealing focus on alternative window managers
  * Don't re-set input focus if the given window already has it
  * Force ANGLE on all pre GCN 4th gen. AMD/ATI GPUs
  * Use render method from OS instead of project settings in compositor RD
  * Add wireframe for compatibility mode
  * Significantly improve the speed of shader compilation in compatibility backend
  and more:
  https://godotengine.github.io/godot-interactive-changelog/#4.2.2
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Fri Feb 16 2024 cunix@mail.de
- Pin mbedtls-devel version to be lower than 3 for Leap builds, too.
* Wed Dec 13 2023 cunix@mail.de
- Update to 4.2.1
  * Set language encoding flag when using "ZIPPacker"
  * Prevent infinite recursion when printing errors
  * Allow dragging editable children in editor
  * Fix errors on file rename or move in the Filesystem Dock
  * X11: Send IME update notification deferred
  * Only allow MeshInstance3D-based nodes in
    particles emission shape node selector
  * Comment the shader template light function by default
  and more:
  https://godotengine.github.io/godot-interactive-changelog/#4.2.1
* Thu Nov 30 2023 cunix@mail.de
- Update to 4.2
  Breaking possible:
  * AnimationMixer between AnimationPlayer and AnimationTree
  * GraphEdit and GraphNode reworked
  * GLTF importer
  * Internal storing of meshes
  * "change_scene_to_"* methods
  * "bus_layout_changed" signal removed in AudioServer
  * NOTIFICATION_NODE_RECACHE_REQUESTED removed
  Some highlights:
  * Onion skinning mode to preview animations
  * 2D navigation mesh baking
  * Multi-threading when baking the navigation mesh
  * Editor code regions
  * Project manager reorganized
  * GDExtension hot reload in editor
  * Import type changes are picked up on the fly
  * KTX image format
  * Native file selection dialogs
  * Copying and pasting images to clipboard
  * OIDN dropped as default denoiser
  * GPU and CPU particles start to deviate
  * Full support for threaded code in script debugger
  and much more:
  https://godotengine.github.io/godot-interactive-changelog/#4.2
- rebased improve_linker_detection.patch
* Tue Nov  7 2023 cunix@mail.de
- Update to 4.1.3
  Added:
  * Support loading of translations on threads
  * GDScript: check for "super()" methods not being implemented
  Changed:
  * Allow using floating-point bone sizes
    and outline widths in the 2D editor
  * Convert TileSet Atlas Merge input images to RGBA8 to match output, if needed
  * Make CSGShape follow curve's tilt in Path mode
  * Initialize View Frame Time estimates to match 120 FPS
  * Animation: Improve and clarify paused Tweens
  * Limit mesh complexity in LOD generation to prevent crashing
  * Update Blender export flags for 3.6
  Fixed:
  * TileMap editor so that pressing control deselects cells correctly
  * GridMap: Ensure the visibility is updated when entering the tree
  * Animation keyframes being skipped when played backwards
  * BoneAttachment3D signal connection
  * SkeletonIK3D editor preview when changing active node
  * Clear the previously set state when configuring for a new scene root node
  * Non-deterministic behavior in PCKPacker
  * Conversion of hex color strings in project converter
  * Indentation in script templates
  * LSP: Fix connection error when launched in a separate thread
  * LSP: Fix autocomplete quote handling
  * Native popups auto-closing when interacting with non-client area
  * Scrolling "PopupMenu" on keyboard/controller input
  * "OptionButton" minimum size when "Fit Longest Item" is enabled
  * 2D/3D viewport context switching issues when script editor is floating
  * Crash when generating LODs on meshes with non-finite vertices
  * Particle shader deterministic random values
  * Use EWMH for "DisplayServerX11::_window_minimize_check()" implementation
  * Ensure "POINT_SIZE" takes effect in the canvas item shader
  * Avoid default fallback material when using "world_vertex_coords"
  * Disabling depth prepass break opaque materials
  and more:
  https://godotengine.github.io/godot-interactive-changelog/#4.1.3
* Thu Oct  5 2023 cunix@mail.de
- Update to 4.1.2
  Added:
  * Check to ensure registered classes are declared
  * Motion vector support for GPU 3D Particles
  * More hint types for uniform arrays in shaders
  * Autocomplete for filter/repeat hints on uniform arrays in shaders
  Changed:
  * Disable C++ exception handling
  * 3D property hint range for camera attributes exposure multiplier
  * Don't use splash minimum display time in editor
  * Automatically add path to built-in scripts
  * Uncollapse favorites by default in the editor FileSystem dock
  * Use "ui_text_submit" instead of "ui_accept"
    to confirm and close text prompts
  * Make editor camera speed indicator use "m/s" and "m"
  * Enable transparent background for GUI tooltips
  * Ensure "joy_connection_changed" is emitted on the main thread
  * Do not fail DisplayServer init if non-essential extensions are missing
  * Enable depth writes during shadow pass and depth pass,
    disable during color pass
  * Clamp Volumetric Fog Length property to prevent rendering issues
  Fixed:
  * Camera2D crash when edited scene root is null
  * "CanvasModulate" logic for modulating the canvas
  * VoxelGI saving VoxelGIData as a built-in file,
    despite being prompted to save it to an external file
  * Curve3D baking up vectors for nontrivial curves
  * Remove animation tracks with correct indices
  * Audio stream generators getting freed accidentally
  * Range error for "Array.slice"
  * Recursion level check for array stringification
  * Global transform validity for "Node2D" and "Control"
  * String conversion for -0.0 float values
  * "generate_random_bytes" for large chunks
  * Improve resolution of script type icons
  * Make the single window mode check more strict
  * Crash when using "Close All Tabs"
  * Version check for GDExtension
  * Overriding "_export_begin", "_export_file" and
    "_export_end" from GDExtension
  * Conflict between property and group names
  * RichTextLabel character line and paragraph index getters
  * Delay on tab resizing when (un)hovering tabs
  * Button clipping when internal margins exist
  * "OptionButton" resize when disabling "Fit to Longest Item"
  * "Button" text when the overrun behavior is other than "No Trimming"
  * Crash when hiding subwindow during popup of new subwindow
  * ItemList not updating when icon scale changes
  * NavigationObstacle2D debug position
  * Prevent crash when accessing "Node" Multiplayer from thread
  * ENet: Better handle truncated socket messages
  * ENet: Properly set transfer flags when using custom channels
  * File permissions set to 0666
  * Shader type detection
  * Shader and ShaderInclude resource loading
  * Empty shader resource loading
  and more:
  https://godotengine.github.io/godot-interactive-changelog/#4.1.2
- added improve_linker_detection.patch for pck embedding with runner
* Wed Jul 19 2023 cunix@mail.de
- Update to 4.1.1
  Added:
  * 3.x compatibility for animation loop mode
  Changed:
  * Allow unbundling brotli to use system library
  * Check parameter validity in "Object::set_script"
  * Focus current node after connecting
  * Sort project tags before saving
  * Project converter: Use same rendering driver as Project Manager
  * Take eye offset into account for depth in StandardMaterial3D
  Fixed:
  * build with "use_sowrap=no" and various warnings/errors
  * "Camera2D.rotating" not being converted and reversed properly
  * 3D viewport grid disappearing on scene tab changes
  * "tween_property" on "Basis" to properly update its value
  * dropping files from "res://" to "res://"
  * Do not change a node unique name to the same name
  * Emit "history_changed" on merged UndoRedo actions
  * Cursor behavior for multiselect in Tree while holding CTRL
  * Invalid minimum size for translated messages in option button
  * Fallback logic of "OS::shell_show_in_file_manage"`
  * Avoid freeze when interacting with menus on Wayland
  * "move_to_trash" wrongly reporting files as not found
  * Threading bug in Vulkan rendering device
- "xkb_loaded.patch" dropped: accepted upstream
* Fri Jul  7 2023 cunix@mail.de
- Update to 4.1
  Added:
  * Platform-specific CA bundles
  * "Center View" button in 2D editor
  * Proper snapping to tile polygon editor
  * Ability to look-at in 3D model-space
  * Move control points button to Path3D Editor
  * "TRANS_SPRING" mode to "Tween"
  * Frame delta smoothing option
  * Square fill mode to GradientTexture2D
  * "ProjectSettings.set_as_basic()" and "ProjectSettings.set_as_internal()"
    exposed  to scripting
  * Let user scripts disable thread safety checks
  * multi-window for code and shader editors
  * Remember snapping options per-project
  * Project tags
  * Make create folder popup support nested folders
  * Relative path support for "EditorPlugin.add_autoload_singleton"
  * Export options for EditorExportPlugins
  * Editor support for icons of custom, scripted, and GDExtension classes
  * Backwards compatibility system for GDExtension
  * GDExtensions allowed to add editor plugins
  * GDExtension "@since" attribute
  * Boolean operators for all Variant types
  * Static variables in GDScript
  * Multiline cells in "Tree"
  * horizontal/vertical "custom_step" editor property for "ScrollContainer"
  * "screen_get_pixel" method
  * Vertical icon alignment for buttons
  * All auto-wrap modes in "TextEdit" exposed
  * Tab stops support in "Label" and "RichTextLabel"
  * "Window.get_window_id()"
  * Method to check if native window is focused
  * Support for extending GLTF with more texture formats and support WebP
  * non-standard OBJ vertex entries supported
  * NavigationAgent path postprocessing and pathfinding algorithm options exposed
  * "audio/general/text_to_speech" project setting to enable/disable TTS
  * Default error handler for X11 to avoid crashes
  * Shader cache for GLES3
  * Vulkan pipeline caching
  * NoiseTexture3D
  * "EXPOSURE" and "LIGHT_IS_DIRECTIONAL" built-in for spatial shaders
  * Option for ButtonGroups to be unpressed
  Changed:
  * Node processing refactored to allow Scene multi-threading
  * Node children management optimized
  * Replace invalid characters in node names by underscores
    instead of removing them
  * Remove constrained view in the 2D editor
  * Reorganize context menu in FileSystem dock
  * Preserve scene unique names when saving branch as scene
  * Allow showing messages from threads in "Editor Log"
  * Store sensitive export options in dedicated credentials file
  * Rework GDExtension interface from a struct to loading function pointers
  * Make "TextureButton" and "Button" update on texture change
  * Use defined key mapping for closing popups and dialogs
  * Disable texture format import overrides by default
  * Navigation mesh edge connections optional
  * Disable weak crypto and TLS versions
  * Propagate previously unused "NOTIFICATION_WORLD_2D_CHANGED",
    make CanvasItem/CollisionObject2D use it
  * Rework particle turbulence
  * (Re-)Implement "Light3D.shadow_reverse_cull_face"
  Fixed:
  * 3D viewport front/rear axis and "Focus" button
  * AudioListener2D ignoring rotation for positional audio
  * Trim when importing WAV
  * Invalid 2D global position when read outside tree
  * "View Owners" dialog not acknowledging that some resources aren't scenes
  * Avoid error spam on first opening of a not yet imported project
  * GDExtension Variant type conversion
  * GDScript access to identifiers that are reserved keywords
  * Ensure that controls update all their sizing information when required
  * Input: just pressed and released with short presses
  * Sliding window problem
  * Temporary file permissions
  and much more:
  https://downloads.tuxfamily.org/godotengine/4.1/Godot_v4.1-stable_changelog_chrono.txt
- "certs_fallback.patch" dropped:
    godot is now aware of openSUSE certs in
    "/var/lib/ca-certificates/ca-bundle.pem"
- "tinyexr_thirdparty_upstream.patch" dropped:
    bundled tinyexr 1.0.5 has patch applied
- "xkb_loaded.patch" added for x11 build failure with "use_sowrap=no"
* Mon May 22 2023 cunix@mail.de
- Update to 4.0.3
  Added:
  * Info label to TileMap editor
  * Properly remember snapping options per-project
  * Remember directory when installing templates file
  * Allow entering named colors in ColorPicker's hex field
  * Expose NavigationAgent path postprocessing
    and pathfinding algorithm options
  * Expose viewports render target RID
  * Allow creation of rendering buffers at any time
  Changed:
  * Make acos and asin safe
  * Prevent off-screen controls in editor
  * Validate renderer selection in project manager
    and expose default renderer setting as an enum
  * Close built-in shaders when closing scene
  * Preserve scene unique names when saving branch as scene
  * gltf: Remove obsolete hack to embed gltf textures in advanced import
  * Expose more compression formats in Image and fix compress check
  * Ensure WindowData minimized/maximized are mutually exclusive
  Fixed:
  * AudioStreamPlayer2D crash when PhysicsServer2D runs on thread
  * Invalid global position when read outside tree
  * Prevent errors when using ViewportTexture
  * Initialize editor values on first launch
  * "line_spacing" in code editor will not take effect
  * Missing member type check when resolving "extends"
  * Multi-line string highlighting with single quotes
  * Don't fail when freed object is returned
  * NavigationObstacles not being added to avoidance simulation
  * Crashes trying to use TLS when not available
  And more:
  https://downloads.tuxfamily.org/godotengine/4.0.3/Godot_v4.0.3-stable_changelog_chrono.txt
* Tue May  2 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Require the mbedtls-devel version to be lower than 3
* Wed Apr  5 2023 cunix@mail.de
- Update to 4.0.2
  Added:
  * Expose "apply_floor_snap" function to allow manual snap
  * Drag and drop support for shader include files in shader editor
  Changed:
  * Cleanup pulseaudio defines for Linux
  * Use 8×8 default grid size for TextureRegion and 2D polygon editors
  * Don't allow selecting nodes without owner in the editor
  * Exit with non-zero status if there are issues with
    FreeType dependencies
  * Remove disabled plugins from active plugins
  * Delete unused compression formats from ".import"
    files when exporting
  * Make GDScript number highlighting stricter
  * Revert attempted fix of trimesh CCD
  * Incorporating the availability of screen and depth
    textures for the GLES3 backend
  Fixed:
  * preview rendering and transform calculations in the tiles editor
  * built-in scripts missing their methods on signal connection
  * GDExtensions library export when multiple architectures are set
  * "Find in Files" search results not opening built-in script
  * scrolling behavior with zero/low page value
  * Layout bug in "keyboard_get_keycode_from_physical"
  * Agents with disabled avoidance getting added to avoidance simulation
  * Spotlight shadows in volumetric fog
  * Update GPUParticles2D/3D speed scale on "ENTER_TREE"
  And more:
  https://downloads.tuxfamily.org/godotengine/4.0.2/Godot_v4.0.2-stable_changelog_chrono.txt
- dropped scons_regression.patch with Scons 4.5.2 available in Tumbleweed
* Wed Mar 22 2023 cunix@mail.de
- Update to 4.0.1
  Added:
  * Set the unlit/unshaded extension when importing/exporting glTF
  * Keycode project conversion
  * Conversion for common Theme Overrides
  * Remember previously selected TileMap tile
  Changed:
  * Check for type mismatch in PropertyTweener.from()
  * Propagate errors when creating an OpenGL context fails in X11
  * Automatically reparent editor message dialogs to avoid error spam
  * Disallow creating a project in the Home or Documents folder
  * No autocomplete numbers in GDScript
  * Add invalid font scaling check, restrict Linux/BSD system fonts
    lookup to TrueType/CFF only (fixes crash in donors screen)
  * Do not convert lines that start with a comment
  * Don't strip whitespace when converting
  * Use linear filtering without mipmaps for ProceduralSkyMaterial
    and PhysicalSkyMaterial
  Fixed:
  * VMA build with GCC 13
  * Don't try to link system embree3 on unsupported archs
  * Logic related to editing audio buses and prevent crashes
  * Set properties of ImageTexture3D when creating
  * Crashing on startup if project has scripted theme types
  * Disable local space for Blender-style transforms
  * Toaster notification circle flickering
  * Crash when showing file in FileSystem dock
  * Cache corruption when saving resources in the editor
  * MultiNodeEdit not cleared after deleting nodes
  * Crash when dumping extension API in a non-writable directory
  * Missing handler for removing font sizes in the theme editor
  * NavigationAgent3D debug path duplicated points
  * Check if required xkb functions exist before using it
  * Broken shortcut key input
  * Avoid copying CanvasTexture when updating proxy
  And more:
  https://downloads.tuxfamily.org/godotengine/4.0.1/Godot_v4.0.1-stable_changelog_chrono.txt
- dropped upstreamed VMA-fix-gcc13.patch.
* Thu Mar  9 2023 cunix@mail.de
- added scons_regression.patch for scons 4.5.1 until 4.5.2
* Thu Mar  9 2023 Martin Liška <mliska@suse.cz>
- Include upstream fix for GCC 13: VMA-fix-gcc13.patch.
* Fri Mar  3 2023 cunix@mail.de
- existing 3.x projects will probably need manual work to port to 4.0
  * BACKUPS NEEDED!
- Update to 4.0
  * 3D & General Rendering Overhaul
    Vulkan & New Renderers
    Highly Improved Lighting & Shadows
    New Rendering Optimization Techniques
    Enhanced Mid & Post-Processing
  * 2D Improvements
    Powerful New 2D Level-Editing Tools
    New 2D Rendering Options
    Improved 2D Lighting & Shadows
  * Shaders & VFX
    New Atmospheric Effects
    Textures & Material Projection
    Enhanced Shader-Game World Interaction
    Improved Shader Editor
    Extended Shader Language
    Compute Shaders
  * Scripting
    GDScript
    static typing system is now more robust
    first-class functions, lambdas and signals
    await and super keywords
    report many errors simultaneously
    automatically generate documentation
    GDExtension (experimental) replaces GDNative
  * Physics
    Game-Specific Physics Engine
    Multithreading & Performance Optimization
    Better Physics API
    Higher Simulation Stability
  * UI and Text
    Multiple Window Support
    UI Editor Improvements
    New Text Rendering Systems
    New Theme and Theme Editor
  * Internationalization
    Extended Language Support
    Easier Translation Workflow
  * Editor & UX
    Easier Importing
    New Editor Features and Widgets
    Inspector Dock Improvements
    Scene Dock Improvements
    Script Editor Improvements
    Easier Version Control
    New Movie Maker Mode
    New Editor Theme
  * Navigation
    Server-Based Navigation System
    Extended Complex Navigation Support
  * XR
    Wider Headset & Platform Support
    Godot XR Tools
  * Networking & Multiplayer
    More Stable Networking Systems
    Simplified Multiplayer Development Workflow
  * Audio
    Cleaner Sound
    Built-in Polyphony
    Music Looping Point and Text-To-Speech
  * Animation
    Enhanced Animation Editor
    Improved 3D Animation Workflow
    Animation Libraries and Retargeting System
    Blending, Transitions and Complex Animation Support
    New Tween Animation System
  * Platform Support
    Android & Web Support
    More Exporting Options
  * and so much more:
    https://downloads.tuxfamily.org/godotengine/4.0/Godot_v4.0-stable_changelog_chrono.txt
- certs_fallback.patch rebased
- drop linker_pie_flag.patch
- dropped separate headless and server packages
* Mon Nov 21 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not have the main package recommend the bash-completion
  sub-package, but rather have the subpackage supplement the
  combination of godot and bash-completion (already in place).
* Fri Sep 30 2022 cunix@mail.de
- Update to 3.5.1
  Added:
  * Expose Tabs "set/get_tab_button_icon()" to scripting
  Changed:
  * Include terminal indented comments for code folding in editor
  * Portals: Show RayCast debug helper
  Fixed:
  * GNU ld detection for pck_embed linker script
  * CPUParticles initialize data on "set_amount"
  * Crash when playing SceneTreeTween right after finishing
  * "Time.get_unix_time_from_system()" not including msecs
  * Crash when pressing up on an empty PopupMenu
  * Exclude disabled StaticBody collisions from NavigationMesh baking
  * Prevent HTTPRequest from polling invalid client
  * Hotfix for Bullet's collision margin regression
  And more:
  https://downloads.tuxfamily.org/godotengine/3.5.1/Godot_v3.5.1-stable_changelog_chrono.txt
* Mon Sep 12 2022 cunix@mail.de
- Heap-buffer-overflow in bundled thirdparty tool tinyexr
  * added tinyexr_thirdparty_upstream.patch from upstream tinyexr (boo#1203278)
* Sat Aug  6 2022 cunix@mail.de
- Update to 3.5
  Added:
  * NavigationServer with obstacle avoidance
  * Physics interpolation in 3D
  * SceneTreeTween
  * Time singleton
  * Label3D node and Sprite3D material render priority
  * Scene unique nodes
  * FlowContainer
  * Asynchronous shader compilation and caching
  * OccluderShapePolygon
  * "material_overlay" property for MeshInstance
  * Transparent background Viewports with post processing effects
  * Changing directional shadows at runtime
  * Setting visibility for CanvasLayer
  * push, pull, fetch and improved diff view to VCS UI
  * "global_translation" and "global_rotation"` to Spatial
  * Option to paste animation as duplicate
  * Configuring loop mode on WAV import
  * Pinning property values and Consistent property defaults
  * Deep comparison of Array and Dictionary
  * methods "OS.is_process_running()", "OS.crash()", "OS.has_clipboard()",
    "OS.get_processor_name()", "OS.get_screen_refresh_rate()",
    "OS.move_to_trash()", "Image.fill_rect()", "String.get_slice()",
    "String.join()", "Dictionary.merge()"
  * Search methods for PoolArrays: "has()", "count()", "find()", "rfind()"
  * Option to keep or skip carriage return (CR) in "File.get_as_text()"
  * GradientTexture2D
  * Signal to notify when children nodes enter or exit tree
  * Alt + Mouse wheel to adjust FOV in the 3D editor viewport
  * Make overridden properties link to parent definition
  * drag and drop for NodePaths
  * drag and drop to TextEdit, LineEdit, RichTextLabel
  * drag start/end signals for Slider
  * Option to make selection unique to TextEdit, LineEdit, RichTextLabel
  * alignment options to Button icons
  * WOFF2 font support and brotli decoder
  * RichTextLabel: "deselect()" and "get_selected_text()" methods
  * Binary MO translation file support
  * Proxy support for HTTPClient and the editor
  * "set_extra_headers()" to WebSocketServer
  * Support for primary clipboard
  * Viewport property to use full floating-point precision in HDR
  * Saving multiple Images in BakedLightmap
  * "max_distance" for VisibilityNotifier
  * "VERTEX_ID" and "INSTANCE_ID" to user created shaders
  * Random initial color feature for all Particles nodes
  Changed:
  * Create onready variables when dropping nodes and holding Ctrl
  * Don't switch to 2D/3D viewports when selecting nodes while in Script Editor
  * Re-enable input accumulation disabled by error in 3.4
  * Navigation and Navigation2D nodes were kept for compatibility but are now
    deprecated. Their functionality is replaced by the NavigationServer
    and Navigation2DServer.
  * WebSocket hostname resolution non-blocking
  * Use application name as PulseAudio device name
  And much more:
  https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_changelog_chrono.txt
- "linker_pie_flag.patch" rebased
- Use bundled freetype, libpng and zlib for non-Tumbleweed builds.
* Tue Aug  2 2022 cunix@mail.de
- Update to 3.4.5
  Added:
  * Expose "tile_texture" property in TilesetEditorContext
  Changed:
  * XR: Update Meta hand tracking version
  Fixed:
  * X11 "OS.is_window_maximized()"
  * Properly check for fullscreen toggle made through the Window Manager
  * Crash in AudioServer when switching audio devices
    with different audio channels count
  * EditorProperty icon overlapping text with checkbox
  * Custom class icon when it inherits from a script
  * UndoRedo in Gradient editor
  * Editor undo history for function name autocompletion
  * FileDialog: Fix support for changing directory in
    "user://" and "res://" modes
  * RichTextLabel: Fix implementation of "remove_line()"
  * glTF texture filename decoding
  * Document that accumulated input is disabled by default
    This is actually due to a regression in 3.4.
    It's kept disabled in this release for compatibility,
    but will be enabled by default in 3.5.
  * GLES2: Unpack blend shape arrays when necessary
  * GLES3: Unbind vertex buffer before calculating blend shapes
  * Portals: Force full check on adding moving object
  And more:
  https://downloads.tuxfamily.org/godotengine/3.4.5/Godot_v3.4.5-stable_changelog_chrono.txt
* Wed Jun 29 2022 Andreas Schwab <schwab@suse.de>
- Fix name of installable binaries
* Sat Mar 26 2022 cunix@mail.de
- Update to 3.4.4
  Reverted:
  * Audio: PitchShift effect quality for different pitch scale values
  * ProjectSettings "has_setting()" when used
    on a overriden setting with feature tags
  Fixed:
  * CSG: visible seam on smoothed sphere, cylinder, and torus shapes
  * CSG: mixed smoothed and non-smoothed face normals computation
  * Portals: duplication of instanced scenes during conversion
  * Animation: cubic interpolate when looping
  * "UndoRedo::create_action()" invalid memory usage
  * RichTextLabel: shadow color when text has transparency
  * Editor: showing "Extend Script" option without script attached
  * Physics: Update joints on "NOTIFICATION_POST_ENTER_TREE"
  * GLES2: compression on blend shapes
  * GLES2: "VersionKey" comparison in shader binding
  * GLES3: shader state caching when blend shapes used
  * GLES3: broken normals in meshes with blend shapes
* Sat Feb 26 2022 cunix@mail.de
- Update to 3.4.3
  Added:
  * TileMap: Expose "autotile_coord"` parameter in "TileMap.set_cellv"
  * Expose "AnimationNodeOneShot::mix_mode" as a property
  Fixed:
  * GridMap: "Convert to MeshLibrary" not respecting collision transforms
  * GridMap: Editing MeshLibrary's Shapes array from the Inspector
  * Portals: gameplay monitor unloading and ticking
  * Portals: DYNAMIC particle systems
  * Potential infinite recursion crash in Variant decoding
  * Decoding UTF-8 filenames on unzipping
  * Replicate load-as-placeholder state on node duplication
  * "ProjectSettings.has_setting()" handle feature overrides
  * Editor: undo/redo operations in Input Map
  * Editor: Performance increase for opening the editor on big projects
  * GDScript: Clear pending function states when reloading script
  * GDScript: crash when "is" keyword is tested against a String variable
  * GUI: Release focus of Control node when exiting tree
  * GUI: LineEdit center and right alignment
  * GUI: PopupMenu bad item offset with custom vseparation
  * GUI: RichTextLabel underline appearance when inside fill tag
  * GUI: RichTextLabel underline prevents strikethrough from rendering
  * GUI: TabContainer not setting layout immediately
  * GUI: TextEdit blocking side scrolling in ScrollContainer
  * GUI: TextureButton focus texture logic
  * GUI: nine patch of circular TextureProgressBar
  * Import: glTF scene export crash on null normal texture
  * Increase joystick max button number
  * HTTPRequest support for requests with "content-length" above 2.1 GB
  * Fix tablet tilt values returning bad values
  * Rendering: blend shapes when octahedral compression is used
  * Rendering: nvalid read when using LightOccluder2D
  * GLES3: Fix visible background line in intersections in screen-space reflections
  And more:
  https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_changelog_chrono.txt
* Wed Dec 29 2021 cunix@mail.de
- Update to 3.4.2
  Fixed:
  * BaseButton's localization for tooltip text with shortcut
  * Size issue for ARVR managed viewport
  And more:
  https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_changelog_chrono.txt
* Sun Dec 19 2021 cunix@mail.de
- Update to 3.4.1
  Added:
  * Expose "ScriptEditor::edit" to scripting
  * TextEdit: Allow toggling bookmark gutter
  * TextEdit: methods to get position from column and line
  * "Input.is_physical_key_pressed()" method
  * Expose "intersect_point" in 3D physics server
  * BVH: option for expanded AABBs in leaves
  * Support for OpenXR export configurations
  Changed:
  * Remove editor splash screen with sponsors logo
  * Clamp rotation for up/down orbiting shortcuts
  * Sort and group theme properties in docs,
    improve formatting for theme and enums
  Fixed:
  * TileSet editor workspace breaking
  * Only add light occlusion for visible TileMaps
  * Selecting next/previous subtile in TileSet editor
  * Swapped rest pose action names in the Skeleton2D editor
  * Theme Editor crash when clicking the element picker
  * Don't ignore the type mismatch in GDScript setter function
  * GDScript: Support multiline indexing with "[]"
  * Prevent LSP adding signal callbacks to non GDScripts
  * RichTextLabel: Right alignment regression
  * RichTextLabel: min/max line width calculation
  * Support for CSG and GridMap in glTF scene export
  * Crash when exporting meshes to glTF that have no skin
  * HTTP request headers being included in response
  * Potential infinite loop when connecting HTTPClient
  * WebRTC returning packets from peers too early
  * Volume calculation for cylinders in GodotPhysics
  * Errors in KinematicBody when floor is destroyed or removed
  * Double use of seed in random Particles shader variables
  * Update CanvasItem when MultiMesh instance transform changes
  * Portals: Allow user to set roaming expansion margin
  * Incorrect VisualServer RID cleanup in various locations
  And more:
  https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_changelog_chrono.txt
* Mon Nov  8 2021 cunix@mail.de
- Update to 3.4
  Added:
  * "AESContext", RSA public keys, encryption, decryption, sign, and verify
  * "HMACContext"
  * Revamped UI theme editor
  * Support for translating the class reference
  * Initial support for the RISC-V architecture
  * Rooms and portals-based occlusion culling
  * Ring emitter for 3D particles
  * Structs and fragment-to-light varyings in shaders
  * Global const arrays in shaders
  * Object validity checks
  * High quality tonemapper
  * Auto-reload scripts with external editor
  * Allow to create a node at specific position
  * Assign value to property by dropping to scene tree
  * Allow dropping property path into script editor
  * Save branch as scene by dropping to filesystem
  * Implement a "%%command%%" placeholder in the Main Run Args settin
  * Keyboard shortcuts to the project manager
  * History navigation in the script editor using extra mouse buttons
  * Focus font color for Button and derivatives
  * ButtonGroup: "pressed" signal
  * ColorPicker: Display previous color and allow selecting it back
  * DynamicFont: Allow using WOFF fonts
  * ScrollBar: "increment_pressed" and "decrement_pressed" icons
  * Theme: support for partial custom editor theme
  * Theme: API to retrieve the default font
  * Improved glTF module with scene export support
  * Lossless WebP encoding
  * Input: physical scancodes to fix non-latin layout scancodes
  * Allow checking for exact matches with action events
  * Multiple address resolution in DNS requests
  * Enable setting the number of physics solver iterations
  * Heightmap collision shape support in Physics 3D
  * Expose collider RID in 2D/3D kinematic collision
  * Support for disabling physics on "SoftBody"
  * GLES2: Add basic support for CPU blendshapes
  * GLES3: Add support for contrast-adaptive sharpening in 3D
  * Soft shadows for the CPU lightmapper
  * High quality glow mode
  * Horizon specular occlusion
  * Shaders: "TIME" available in custom functions by default
  * Allow dropping custom node scripts in VisualScript editor
  * Frame delta smoothing
  * OS data directory getter methods exposed
  * Getter for the project data directory
  * BVH thread safety
  * Property "Engine.print_error_messages" to disable printing errors
  * Setting to configure number of threads for lightmap baking
  * Allow for platform "Thread" implementation override
  * Method "Thread.is_alive()" to check if the thread is still doing work
  * Method "String::parse_url()" for parsing URLs
  * Property "dtls_hostname" for ENet
  * Animation "reset" track
  * Options to clean/simplify convex hull generated from mesh
  * 2D Viewport scale factor property
  * LSP: support for custom host setting
  Changed:
  * Most recently added current "Camera2D" takes precedence
  * Add Node name to "print()" of all nodes
  * Thread callbacks can now take optional parameters
  * "AStar.get_available_point_id()" returns 0 instead of 1 when empty
  * Button: Don't change hovering during focus events
  * DynamicFont: Re-add support for kerning
  * LineEdit: Double click selects words, triple click selects all the content
  * Return RID instead of Object ID in "area"-/"body_shape_entered"/-"exited"
  * "VisualServer" now sorts based on AABB position
  * Default shader specular render mode to "SCHLICK_GGX"
  Fixed:
  * Make all file access 64-bit
  * Ignore property groups and categories in GDScript code completion
  * LSP: "SymbolKind" reporting wrong types and better "get_node()" parsing
  * Breaking Compatibility: swapped axes in "OpenSimplexNoise.get_image()"
  And much more:
  https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_changelog_chrono.txt
- "certs_fallback.patch" and "linker_pie_flag.patch" rebased
* Tue Oct  5 2021 cunix@mail.de
- Update to 3.3.4
  Added:
  * AStar Error messages
  Changed:
  * Compare signal connections by ObjectID to avoid spurious
    reordering in .tscn files.
  * Remove deprecation warning for BaseButton.enabled_focus_mode
  * LinkButton's text is now automatically translated.
  Fixed:
  * LocalVector crash on insert
  * Quote and escape ConfigFile keys when necessary.
  * invalid "Too many warnings!" error in remote script debugger
  * setting NodePath properties on multiple nodes at once
  * preview grid and preserve source texture margins
    in SpriteFrames editor
  * LSP: Fix completion crashing on scene-less scripts
  * CSG: Don't update CSGShape when not inside tree
  * drawing current tab when it's disabled
  * GLES3: Fix multimesh being colored by other nodes
  * GLES3: Properly clear cubemap filter state
    when texture array environment disabled
  * GLES3: Fix Light2D UBO initialization
  * Prevent shaders from generating code before the constructor finishes
  * Fix VisualScriptPropertySet value hint
  * LineEdit undo crash
  And more:
  https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_changelog_chrono.txt
* Fri Aug 20 2021 cunix@mail.de
- Update to 3.3.3
  Added:
  * "action_get_deadzone()" method to InputMap
  Changed:
  * GraphEdit: Allow higher and lower maximum zoom values
  * Copy the Godot version identifier by clicking it
  * Separate version hash from version number
  * Relationship lines draw on top of TreeItems
  * Allow reading shaders from .gdshader files
  Fixed:
  * Audio: cubic resampling algorithm
  * Save binary "ProjectSettings" key length
  * Editor: Slow load/save of scenes with many instances of the same script
  * Editor: Logic for showing tilemap debug collision
  * LSP: Implement "didClose" notification
  * LSP: "SymbolKind" reporting wrong types
  * glTF Import: mesh nodes which are also bones
  * Import RLE compressed TGA files
  * Game controllers ignoring the last listed button
  * Parsing some IPv6 URLs for WebSocket
  * WebsocketPeer outbound buffer
  * IP address resolution incorrectly locking the main thread
  * PathFollow: Forward calculation for the position at the end of the curve
  * RichTextLabel: Fix auto-wrapping on CJK texts
  * SkeletonIK: Bones become detached if multiple SkeletonIK nodes are used
  * Physics: calculating inertias for bodies without mass/area
  * Physics: Ignore disabled shapes for mass property calculations
  * ALSA MIDI with PulseAudio
  * "Directory::get_space_left()"
  * VisualServer now sorts based on AABB position
  * Depth sorting of meshes with transparent textures
  * CanvasItem bounding rect calculation
  * Allow unclamped colors in Sprite3D
  And more:
  https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_changelog_chrono.txt
* Fri Aug  6 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use asimdrdm CPU flag for aarch64 to select only more powerful
  buildhosts.
* Thu Jun  3 2021 cunix@mail.de
- Exclude currently failing %%arm builds
* Tue May 25 2021 cunix@mail.de
- Update to 3.3.2
  Added:
  * GDScript: Allow "warning-ignore" in the same line
    as the respective warning
  * Import: Print warning when importing a
    repeating NPOT texture in a GLES2 project
  Changed:
  * Remove high radiance sizes from the editor due to issues on specific GPUs
  Fixed:
  * STL to Godot type conversion of polypartition
  * Duplicate close file when deconstructing ZipArchive
  * Swapped front/rear directions in viewport rotation control
  * Editor crash when exporting profiler data
  * glTF: Improved error handling around invalid images and invalid meshes
  * ragdoll simulation when parent was readded to scene
  * Crash on debug shapes update if CollisionObject is not in tree
  * Batching: "item_batch_flags" stale state causing glitches
* Fri May 21 2021 cunix@mail.de
- Update to 3.3.1
  Added:
  * Expose "Shape.get_debug_mesh()" to the scripting API
  * Add Ctrl+Shift+A to instance scene in Scene Tree dock
  * Allow negative contrast values in the editor theme settings
  * TileMap: Apply modulate on autotile previews
  * Add support for ARM64 architecture for the Embree raycaster
  Changed:
  * Create "CollisionObject" debug shapes using VisualServer
  Fixed:
  * SkeletonIK root bones being twisted incorrectly when rotated
  * Skinning initialization in "MeshInstance" when loaded from thread
  * Linux packaging fixes
  * ZIP files being opened with two file descriptors
  * CSG Path Polygon cache being removed after connect
  * LineEdit: Fix double click to select words
    and triple click to select whole line
  * Race condition in font preview generation
    could lock the editor on first edit
  * 3D scene preview generation
  * Handle having no sinks in the PulseAudio driver
  * Batching: GLES3 light pass modulates
  * Batching: Crash with wrong number of verts in translation
  * Batching: Fallback for 2D skinning with unrigged polygons
  * Lightmapper: Fixes to environment energy
  * Disable GIProbe emission when disabled on a material
- "use_system_zlib_for_fbx.patch" dropped - fixed upstream
- aarch64 and %%arm: enable modules lightmapper_cpu_enabled and raycast_enabled
* Thu Apr 29 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable modules unsupported on aarch64 and %%arm:
  * module_denoise_enabled
  * module_lightmapper_cpu_enabled
  * module_raycast_enabled
* Thu Apr 22 2021 cunix@mail.de
- Update to 3.3
  Added:
  * MP3 loading and playback support
  * AudioEffectCapture to access the microphone in real-time
  * New dynamic BVH for rendering and the GodotPhysics backends
  * Ability to restore RandomNumberGenerator state
  * "Array.append_array()" method to append an array
    at the end of another array
  * "OS.set_environment()" method to set environment variables
  * Infinite 3D editor grid
  * New 3D rotation gizmo
  * Support for copy-pasting nodes
  * Detect external modification of scenes and prompt for reloading
  * New editor to configure default import presets
  * 3D viewport's View Information pane displays viewport resolution
  * Minimap support in GraphEdit
  * New AspectRatioContainer Control node
  * Rewritten and greatly improved FBX importer
  * "Keep" mode to keep files as-is and export them
  * Mouse event pass-through support for the window
  * Support for pause-aware picking (breaks compatibility but only
    enabled by default for new projects)
  * CollisionObject can now display collision shape meshes
  * Cylinder collision shape support
  * PulseAudio and ALSA libraries are now dynamically loaded
  * Implement the "--no-window" command line argument
  * 2D batching for GLES3
  * Configurable amount of lights per object
  * New CPU lightmapper
  * Anisotropic filtering now works when using the GLES2 backend
  Changed:
  * Deleted object access now raises an error instead of a warning
  * Improved error messages when passing nonexistent node paths
    to "get_node()"
  * Modernized multi-threading APIs
  * SVG images can now be used as a project icon
  * Improved inspector subresource editing visibility
  * Pressed CheckButtons are now colored in blue for easier recognition
  * Rename Node is now bound to "F2" key
  * Search Help shortcut from keys "Shift + F1" changed to "F1"
  * The inspector now allows using a comma as a decimal separator
  * Drag-and-dropping a ZIP archive to the project manager window
    will now prompt for importing it
  * Increase the default HTTPClient download chunk size to 64 KiB
  * Binaries are now stripped of string and symbol tables,
    reducing their size significantly
  Removed:
  * ResourceImporterCSV importer superseded by the new "keep" import mode
  Fixed:
  * Use higher-quality resampling for Ogg Vorbis and MP3 sounds
  * exporting if the temporary export directory doesn't exist yet
  * Export PCK/ZIP action now obeys the export path configured
    in the export preset as expected
  * UDP ports being silently reused without an error in PacketPeerUDP
  * keyboard input lag and clipboard delay issues
  And more:
  https://downloads.tuxfamily.org/godotengine/3.3/Godot_v3.3-stable_changelog_chrono.txt
- "linker_pie_flag.patch" rebased
- "upstream_fix_TGA_loader.patch" dropped - included in source now
- "use_system_zlib_for_fbx.patch" added to force using system zlib
* Sat Feb 13 2021 cunix@mail.de
- Fix a crash in the TGA loader with malformed input
  * added upstream_fix_TGA_loader.patch from upstream
  * integer overflow issue CVE-2021-26825 (boo#1182177)
  * stack overflow issue CVE-2021-26826 (boo#1182178)
* Sun Nov  1 2020 Yunhe Guo <i@guoyunhe.me>
- Fix AppStream file location to match latest standard
* Fri Sep 18 2020 cunix@mail.de
- Update to 3.2.3
  Added:
  * Input: Support SDL2 half axes and inverted axes mappings
  * LineEdit: Add option to disable virtual keyboard for LineEdit
  * Rendering: Allow nearest neighbor lookup when using mipmaps
  Changed:
  * GDScript: Auto completion enhanced for extends and
    class level identifier
  * Physics: Better damping implementation for Bullet rigid bodies.
    If you're using damping with the Bullet backend,
    you may need to adjust some properties to restore
    the behavior from 3.2.2 or earlier.
  * Project Settings: Enable file logging by default on desktops
  * Script editor: Don't open dominant script in external editor
  * Sprite3D: Use mesh instead of immediate for drawing Sprite3D
  Fixed:
  * Core: debugger error when Dictionary key is a freed Object
  * Core: leaked ObjectRCs on object Variant reassignment
  * GLES3: OpenGL error when generating radiance
  * Import: custom tracks causing issues on reimport
  * Import: regression causing crashes with some OGG files
  * Particles: 2D Particle velocity with directed emission mask
  * PathFollow3D: repeated updates of PathFollow3D Transform
  * Physics: Trigger broadphase update when changing collision layer/mask
  * Physics: laxist collision detection on one way shapes
  * Physics: Properly pass safe margin on initialization
  * Project Settings: overriding compression related settings
  * Rendering: images in black margins
  * Rendering: Properly calculate Polygon2D AABB with skeleton
  * Shaders: specular 'render_mode' for Visual Shaders
  And more:
  https://downloads.tuxfamily.org/godotengine/3.2.3/Godot_v3.2.3-stable_changelog_chrono.txt
- "certs_fallback.patch" rebased
* Wed Jul  1 2020 cunix@mail.de
- In .desktop file prefix "PrefersNonDefaultGPU" with "X-" only
  until package desktop-file-utils is up to date.
* Fri Jun 26 2020 cunix@mail.de
- In .desktop file "PrefersNonDefaultGPU" prefixed with "X-"
* Fri Jun 26 2020 Max Mitschke <maxmitschke@fastmail.com>
- Update to 3.2.2
  Highlights:
  * 2D batching for the GLES2 renderer
  * C# support for the iOS platform
  * Re-architecture of the Android plugin system
  * DTLS support and ENet integration
  * Better handling of Variants pointing to released Objects
  * Updated and localized documentation
  Added:
  * 2D: MODULATE builtin for canvas item shaders
  * Editor: rotation widget in 3D viewport
  * Editor: Allow duplicating files when holding Control
  * GLES2/GLES3: support for OpenGL external textures
  * Import: support for glTF lights
  * Input: keyboard layout enumeration / set / get functions
  * Object: has_signal method
  * RegEx: Enable Unicode support for RegEx class
  * Shaders: shader time scaling
  * Add 'custom_modules' build option to compile external user modules
  * SCons: Allow to read 'custom_modules' option via a file
  * Provide the ability for clients of the Godot library
    to add their own command line arguments
  * Request the dedicated GPU when starting Godot from the '.desktop' file
  * set_frame, pause, and oneshot to AnimatedTexture
  * selection outline to locked nodes
  Fixed:
  * Audio: volume interpolation in positional audio nodes
  * Import: changing the import type of multiple files at once
  * Particles: uninitialized memory in CPUParticles and CPUParticles2D
  * Physics: Make soft body completely stiff to attachment point
  * Physics: Normalize up direction vector in move_and_slide()
  * Account for file deletion and renaming in Export Presets
  * can't convert Transform -> Transform2D
  * Emit signal when animation ends by seek
  * Othographic camera in-editor now uses Z near/far settings
    instead of a hardcoded value
  * Editor 2D: Change pixel alignment strategy, jittering in high zoom
  * Allow single quotes in comments
  And more:
  https://downloads.tuxfamily.org/godotengine/3.2.2/Godot_v3.2.2-stable_changelog_chrono.txt
- "linker_pie_flag.patch" adjusted.
* Tue Mar 10 2020 cunix@mail.de
- Update to 3.2.1
  Fixed:
  * Bullet: Fix detection of concave shape in Area.
  * Camera2D: Fix inverted use of Camera2D offset_v.
  * Debugger: Fix crash inspecting freed objects.
  * Expression: Fix parsing integers as 32-bit.
  * Particles: Fix undefined behavior with atan in GPU Particles.
  * TileSet: Hide TileSet properties from Inspector, fixing
    OOM crash on huge tilesets.
  * Video: Workaround WebM playback bug after AudioServer latency fixes.
  Added:
  * Skin: Add support for named binds.
  * API documentation updates.
  * Editor translation updates.
  And more:
  https://downloads.tuxfamily.org/godotengine/3.2.1/Godot_v3.2.1-stable_changelog_chrono.txt
- "linker_pie_flag.patch" adjusted.
* Wed Feb 12 2020 cunix@mail.de
- Added "linker_pie_flag.patch" in order to link with "-pie".
    Replaces previous "fix-pie-warning.patch".
- "project_certs_fallback.patch" renamed to "certs_fallback.patch".
    Modified and adapted to Godot source code changes.
- Bash completion files "godot", "godot-headless", "godot-runner"
    and "godot-server" added.
- Package "godot-bash-completion" added.
- Location of documentation in man page adjusted.
- godot-rpmlintrc deleted with filter "no-manual-page-for-binary"
    because this warning doesn't seems to be thrown anymore.
- Build option "faster_build" introduced to speed up build
    during tests.
* Sat Feb  1 2020 Max Mitschke <maxmitschke@fastmail.com>
- Removed patch "fix-pie-warning.patch"
- Removed export_presets.cfg file as games should supply this file
- Update to v3.2
  Added:
  * Support for importing 3D scense using Assimp
  * Support for high-level multiplayer API and NAT traversal for
    WebRTC
  * Support for enabling / disabling parts of the editor or specific
    nodes
  * Added language server for GDScript
  * Added version control integration into the editor
  * Added a network profiler
  * Editor is now capped to 20FPS when the window is unfocused
  * Added MSAA support in the GLES2 renderer
  * Ability to define script templates on a per-project basis
  * Ability to limit the minimum and maximum window size
  * Minimap in the script editor
  * CSV files can now be imported as non-translation files
  * Multicast support in PacketPeerUDP
  * WebSocket improvements.
  * Support for SSL in WebSocketServer.
  * WebSocketClient can now use custom SSL certificates
    (except on HTML5).
  * WebSocketClient can now define custom headers.
  * The editor now features a built-in Web server for testing HTML5
    projects
  * Reimplemented support for embedding project data in the PCK file
  Changed:
  * Tabs and space indentation can no longer be mixed in the same
    GDScript file
  * assert() in GDScript must now always be used with parentheses
  * UDP broadcasting is now disabled by default and must be enabled
    by calling
    set_broadcast_enabled(true) on the PacketPeerUDP instance
  * 3D collision shapes and RayCasts are now drawn in gray when disabled
  * The SCons build system now automatically detects the host platform
  * Exporting a project PCK or ZIP from the command line must now
    be done with the new --export-pack command-line argument
  * Exported PCK files now contain the Godot patch version in their
    header
  * "Set as Main Scene" context option for scenes in the FileSystem dock
  Removed:
  * Unused Panel panelf and panelnc styles.
  * thekla_atlas dependency, as light baking now relies on xatlas
    for UV unwrapping.
  * Rating icons in the Asset Library
  * Some editor languages are no longer available due to missing
    support for RTL and text shaping in Godot.
  * Arabic
  * Bengali
  * Persian
  * Hebrew
  * Hindi
  * Malayalam
  * Sinhalese
  * Tamil
  * Telugu
  * Urdu
  * Android: ARMv6 support.
  * iOS: ARMv7 support.
  Fixed:
  * The Project Manager now remembers the sorting option that was
    previously set
  * Fixed issues with PBR environment mapping
  * Several fixes to the GLES2 renderer
  * Fixed importing BMP images
  * Exporting a project via the command-line now returns a non-zero
    exit code if an error occurred during exporting
  * Fixed autocompletion in the script editor
  And more:
  https://github.com/godotengine/godot/blob/3.2/CHANGELOG.md
* Mon Jan 13 2020 cunix@mail.de
- Sources replaced by upstream without version bump
  to hotfix export templates for HTML5 platform
* Tue Dec  3 2019 Max Mitschke <maxmitschke@fastmail.com>
- Updated bundled library versions within specfile
- Cleaned up specfile
  * Removed defattr directives
  * Use %%license directive for license files
* Sat Nov 30 2019 Martin Liška <mliska@suse.cz>
- Update to 3.1.2
  Fixed:
  * Animation: Fixes for onion skinning support of Skeleton2D
  * AnimationTree: Fixes to AnimationTree and State Machine
  * Audio: Fix seemingly random crashes related to the audio engine misusing
    internal processing
  * CPUParticles(2D): Various fixes
  * GLES2: Many bugfixes
  * GLES3: Many bugfixes
  * Editor: Fix issues when moving and renaming files
  * Export: Fix resetting editor settings when exporting from the
    command line
  * Import: Various improvements to BMP support
  * Internationalization: Various fixes to Control localization,
    and fixes to support of some regional locales
  * iOS: Fix crash on resume/exit on iOS 13
  * macOS: Fix non-HiDPI mode on HiDPI displays on macOS Catalina
  * macOS: Fix locale detection when running from .app bundle
  * Object: Improve instance validation, mitigating thread-related issues
  * Shaders: Fix support for hint_range using integers
  Added:
  * Editor: Allow to removing 2D editor limits
  * Mobile: Add vibration support on Android and iOS
  * TileMap: Add support for negative Y and X offsets
  * API documentation updates.
  * Editor translation updates.
  Third Party Libraries:
  * zstd upgraded to 1.4.4
  * libwebsockets downgraded to 3.0.1 (3.1 caused regressions)
* Sun May 12 2019 Max Mitschke <maxmitschke@fastmail.com>
- Fixing packaging issues for submission to Factory
  * Changed python build requirement for python3
  * Removed no-version-in-last-changelog from rpmlintrc
  * Renamed rpmlintrc to godot-rpmlintrc per openSUSE packaging
    standards
* Mon Apr 29 2019 cunix@bitmessage.ch
- Use system certificates from /var/lib/ca-certificates/ca-bundle.pem
  by default and dynamically. Stop hard coding its content during build.
  These certificates are used by the editor to connect to the Asset Library.
- Added patch file "project_certs_fallback.patch" to use the previously
  defined system certificates as fallback for missing certificates in
  project setting "network/ssl/certificates".
* Sun Apr 28 2019 cunix@bitmessage.ch
- Changes in 3.1.1
  Fixed Security Issue:
  * to deserialize Object data. GDNative ABI was changed.
  Fixed:
  * GLES 3 support for depth textures.
  * GLTF2 importer
  Added:
  * HeightMapShape to the Bullet physics engine implementation
  * FPS snapping in the Animation player
  * audio features for 3.2 were backported
  * menu options for the Sprite editor: "Convert to Mesh2D",
    "Convert to Polygon2D", "Create CollisionPolygon2D Sibling"
    and "Create LightOccluder2D Sibling"
  * AnimatedSprite can now play backwards
  * Emission Mask to CPUParticles2D
  And more:
  https://downloads.tuxfamily.org/godotengine/3.1.1/Godot_v3.1.1-stable_changelog.txt
* Sun Apr 28 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
- Require bash for the build due to use of [[ x > y ]].
* Sat Apr 27 2019 Martin Liška <mliska@suse.cz>
- Update to 3.1.1
* Sat Apr 27 2019 Martin Liška <mliska@suse.cz>
- Mention rpmlintrc as a source file.
* Tue Apr 16 2019 Max Mitschke <maxmitschke@fastmail.com>
- Update to 3.1
  * See https://github.com/godotengine/godot/blob/3.1-stable/CHANGELOG.md
* Thu Mar  7 2019 Max Mitschke <maxmitschke@fastmail.com>
- Added export_presets.cfg to be used when one is not present in
  Godot game's source.
* Tue Mar  5 2019 Max Mitschke <maxmitschke@fastmail.com>
- Added godot-headless package
* Tue Feb 26 2019 Martin Liška <mliska@suse.cz>
- Disable lto for anything older than openSUSE 15.0.
* Tue Feb 19 2019 Martin Liška <mliska@suse.cz>
- Rename subpackages to godot-runner and godot-server in order
  to provide same names as in Fedora package
- Do not use -fno-strict-aliasing
- Make output verbose and use LTO (increase RAM requirements).
* Mon Feb 18 2019 cunix@bitmessage.ch
- Added patches to use system certificates
- Added service file for local hash checking
- Added rpmlintrc file to silence warning of missing version in
    changelog and for missing manual-page for server package
* Tue Feb  5 2019 Ferdinand Thiessen <rpm@fthiessen.de>
- Use https://en.opensuse.org/SourceUrls
* Wed Jan 30 2019 maxmitschke@fastmail.com
- Updated spec file to better align with openSUSE package
  guidelines
* Sun Jul 29 2018 cunix@bitmessage.ch
- Update to 3.0.6
  Fixed Security Vulnerability:
  * marshalls size checks
  Fixed:
  * vsync initialization
  * can't set AudioStreamPlayer stream to null
  * Basis.Transposed()
  * Several editor crashes
  * GLTF import fixes
  and more
  Upgrade:
  * OpenSSL to 1.0.2o (not used in openSUSE build)
* Wed Jul 11 2018 cunix@bitmessage.ch
- spec changes:
  * build with more shared libraries from the distribution
    instead of bundled versions
  * make build of templates optional
  * unify repetive build arguments
  * include thirdparty/README.md in licenses section
* Tue Jul 10 2018 maxmitschke@fastmail.com
- Update to 3.0.5
  * Android export templates no longer contain the placeholder
    permissions which Google Play started complaining about. Now
    only requested permissions will be written to the manifest when
    exporting.
  * Added 'android_add_asset_dir('...') method to Android module
    gradle build config
  * User defined signals in the exported C# projects were
    misbehaving, this is now fixed.
  * Fix CORS problems due to added headers on JS target
  * Lerp now consistent with Godot API. InverseLerp fixed.
  * Fix debugger focus stealing
  * Fix segfault at quiting editor
* Sun Jul  1 2018 maxmitschke@fastmail.com
- Added openSUSE branding to build info
- Use upstream desktop file, appdata.xml and manpage
- Licenses relocated
- Require update-desktop-files post and postun
- desktop_database only updating explicitly for Leap < 15.0
- Update to 3.0.4
  * Updated documentation for particles, ViewportTexture, Vector2,
    skeleton docs, Rect.abs function
  * Make heightmap shape usable from PhysicsServer
  * Add NoCache wrapper to Command
  * Fixed crasher in asset library on systems with a low threadcount CPU
* Sun Jun 17 2018 maxmitschke@fastmail.com
- Update to 3.0.3
  Added:
  * C# projects can now be exported for Windows, Linux, and MacOS targets.
  * Universal translation of touch to mouse.
  * Dynamic fonts can now have a hinting mode set.
  * print_tree_pretty() was added allowing a graphical view of the scene tree.
  * Restore purchases feature for iOS.
  * AudioStreamPlayer, AudioStreamPlayer2D,
    and AudioStreamPlayer3D now have a pitch scale property.
  * Show origin and Show viewport setting in 2D editor.
  * You can now set Godot windows as 'always on top'.
  * print-fps options to print FPS to stdout.
  Fixed:
  * Mono: Signal parameters no longer crash the engine.
  * Asset library thread usage, this makes the asset library more responsive.
  * Several GLTF import fixes.
  * Several memory leaks.
  * iPhone X support.
  * Several fixes to audio drivers (WASAPI and PulseAudio).
  * Several crashes.
  * Export PCK/ZIP now works again.
* Sat Mar 10 2018 cunix@bitmessage.ch
- Update to 3.0.2
* Tue Feb 27 2018 gwasser@gmail.com
- Update to 3.0.1
* Tue Jan 30 2018 gwasser@gmail.com
- Update to 3.0.0
* Tue Sep  5 2017 dmacvicar@suse.de
- Update to 2.1.4
* Fri Feb 10 2017 luke.nukem.jones@gmail.com
- Update to 2.1.2
- Add appdata.xml
- Remove fix-arch-detection.patch
- Remove fix-undefined-return.patch
* Mon Jun 27 2016 rpm@fthiessen.de
- Update to 2.0.3
- Added fix-arch-detection.patch to fix ppc build
- Added fix-undefined-return.patch to fix functions with random
  return.
* Mon Jun  1 2015 gber@opensuse.org
- add desktop file
* Sun May 31 2015 gber@opensuse.org
- split examples into subpackage
* Sun May 31 2015 gber@opensuse.org
- initial packaging
